# -*- coding: UTF-8 -*-

from artix.common.py2to3utils import configparser
from singleton import Singleton
import logger
import os
import platform
import sys


class InfoReader:
    __metaclass__ = Singleton
    configPath = os.path.normpath('%s/../properties/version.info' % sys.path[0])

    def __init__(self):
        self.package = None
        self.version = None
        self.platformIsBionic = 'Ubuntu-18.04-bionic' in platform.platform()
        # Считывание настроек подключения sync-агента
        if os.access(InfoReader.configPath, os.F_OK):
            info = configparser.RawConfigParser()
            info.read(InfoReader.configPath)
            self.package = InfoReader.__getValue('package', None, info)
            self.version = InfoReader.__getValue('version', None, info)

    @staticmethod
    def __getValue(option, defaultValue, config):
        """
        Получить значение опции из конфигурационного файла.
        В случае ошибки вернуть значение по умолчанию
        """
        loggerSync = logger.getLogger()
        value = None
        try:
            if type(defaultValue) is int:
                value = config.getint('Info', option)
            elif type(defaultValue) is bool:
                value = config.getboolean('Info', option)
            else:
                value = config.get('Info', option)
        except (configparser.NoOptionError, configparser.NoSectionError):
            loggerSync.warning(u'Не найдена настройка %s. Берем значение по умолчанию: %s' % (option, defaultValue))
            value = defaultValue

        loggerSync.info(u'%s - %s' % (option.ljust(40, ' '), str(value).ljust(20, ' ')))
        return value


infoReader = InfoReader()
